=======
Credits
=======

Development Lead
----------------

* Taoufik El Aoumari (forked from version 0.2, 2009-01-25)
* Nekmo <contacto@nekmo.com>
* Alicia Boya García (ntrrgc)

Contributors
------------

None yet. Why not be the first?
